==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGroupingExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebGroupingExpressionDescription } from "./WebGroupingExpressionDescription";
/**
 * @hidden
 */
var WebGroupingExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGroupingExpressionDescriptionMetadata, _super);
    function WebGroupingExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingExpressionDescriptionMetadata.b = function (a) {
        if (WebGroupingExpressionDescriptionMetadata.a == null) {
            WebGroupingExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingExpressionDescriptionMetadata.c(WebGroupingExpressionDescriptionMetadata.a);
        }
        if (a.j(WebGroupingExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupingExpressionDescriptionMetadata.a);
    };
    WebGroupingExpressionDescriptionMetadata.c = function (a) {
        WebSortingExpressionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GroupingExpression");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebGroupingExpressionDescriptionMetadata.d = function (a) {
        WebGroupingExpressionDescriptionMetadata.b(a);
        a.aa("WebGroupingExpression", function () { return new WebGroupingExpressionDescription(); });
        a.z("WebGroupingExpression", WebGroupingExpressionDescriptionMetadata.a);
    };
    WebGroupingExpressionDescriptionMetadata.$t = markType(WebGroupingExpressionDescriptionMetadata, 'WebGroupingExpressionDescriptionMetadata');
    WebGroupingExpressionDescriptionMetadata.a = null;
    return WebGroupingExpressionDescriptionMetadata;
}(Base));
export { WebGroupingExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGroupingExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebGroupingExpressionDescription } from "./WebGroupingExpressionDescription";
/**
 * @hidden
 */
var WebGroupingExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGroupingExpressionDescriptionMetadata, _super);
    function WebGroupingExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingExpressionDescriptionMetadata.b = function (a) {
        if (WebGroupingExpressionDescriptionMetadata.a == null) {
            WebGroupingExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingExpressionDescriptionMetadata.c(WebGroupingExpressionDescriptionMetadata.a);
        }
        if (a.k(WebGroupingExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupingExpressionDescriptionMetadata.a);
    };
    WebGroupingExpressionDescriptionMetadata.c = function (a) {
        WebSortingExpressionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GroupingExpression");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebGroupingExpressionDescriptionMetadata.d = function (a) {
        WebGroupingExpressionDescriptionMetadata.b(a);
        a.ac("WebGroupingExpression", function () { return new WebGroupingExpressionDescription(); });
        a.ab("WebGroupingExpression", WebGroupingExpressionDescriptionMetadata.a);
    };
    WebGroupingExpressionDescriptionMetadata.$t = markType(WebGroupingExpressionDescriptionMetadata, 'WebGroupingExpressionDescriptionMetadata');
    WebGroupingExpressionDescriptionMetadata.a = null;
    return WebGroupingExpressionDescriptionMetadata;
}(Base));
export { WebGroupingExpressionDescriptionMetadata };
